@@ -23,7 +23,7 @@ from typing import TYPE_CHECKING, Any, Sequence
 from deprecated import deprecated
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowSkipException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.amazon.aws.hooks.batch_client import BatchClientHook
 from airflow.providers.amazon.aws.triggers.batch import BatchJobTrigger
 from airflow.sensors.base import BaseSensorOperator
@@ -42,6 +42,10 @@ class BatchSensor(BaseSensorOperator):
 
     :param job_id: Batch job_id to check the state for
     :param aws_conn_id: aws connection to use, defaults to 'aws_default'
+        If this is None or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
     :param region_name: aws region name associated with the client
     :param deferrable: Run sensor in the deferrable mode.
     :param poke_interval: polling period in seconds to check for the status of the job.
@@ -57,7 +61,7 @@ class BatchSensor(BaseSensorOperator):
         self,
         *,
         job_id: str,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         region_name: str | None = None,
         deferrable: bool = conf.getboolean("operators", "default_deferrable", fallback=False),
         poke_interval: float = 30,
@@ -82,18 +86,7 @@ class BatchSensor(BaseSensorOperator):
         if state in BatchClientHook.INTERMEDIATE_STATES:
             return False
 
-        if state == BatchClientHook.FAILURE_STATE:
-            # TODO: remove this if block when min_airflow_version is set to higher than 2.7.1
-            message = f"Batch sensor failed. AWS Batch job status: {state}"
-            if self.soft_fail:
-                raise AirflowSkipException(message)
-            raise AirflowException(message)
-
-        # TODO: remove this if block when min_airflow_version is set to higher than 2.7.1
-        message = f"Batch sensor failed. Unknown AWS Batch job status: {state}"
-        if self.soft_fail:
-            raise AirflowSkipException(message)
-        raise AirflowException(message)
+        raise AirflowException(f"Batch sensor failed. AWS Batch job status: {state}")
 
     def execute(self, context: Context) -> None:
         if not self.deferrable:
@@ -123,12 +116,7 @@ class BatchSensor(BaseSensorOperator):
         Relies on trigger to throw an exception, otherwise it assumes execution was successful.
         """
         if event["status"] != "success":
-            message = f"Error while running job: {event}"
-            # TODO: remove this if-else block when min_airflow_version is set to higher than the version that
-            # changed in https://github.com/apache/airflow/pull/33424 is released (2.7.1)
-            if self.soft_fail:
-                raise AirflowSkipException(message)
-            raise AirflowException(message)
+            raise AirflowException(f"Error while running job: {event}")
         job_id = event["job_id"]
         self.log.info("Batch Job %s complete", job_id)
 
@@ -156,6 +144,10 @@ class BatchComputeEnvironmentSensor(BaseSensorOperator):
     :param compute_environment: Batch compute environment name
 
     :param aws_conn_id: aws connection to use, defaults to 'aws_default'
+        If this is None or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
 
     :param region_name: aws region name associated with the client
     """
@@ -167,7 +159,7 @@ class BatchComputeEnvironmentSensor(BaseSensorOperator):
     def __init__(
         self,
         compute_environment: str,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         region_name: str | None = None,
         **kwargs,
     ):
@@ -190,11 +182,7 @@ class BatchComputeEnvironmentSensor(BaseSensorOperator):
         )
 
         if not response["computeEnvironments"]:
-            message = f"AWS Batch compute environment {self.compute_environment} not found"
-            # TODO: remove this if block when min_airflow_version is set to higher than 2.7.1
-            if self.soft_fail:
-                raise AirflowSkipException(message)
-            raise AirflowException(message)
+            raise AirflowException(f"AWS Batch compute environment {self.compute_environment} not found")
 
         status = response["computeEnvironments"][0]["status"]
 
@@ -204,11 +192,9 @@ class BatchComputeEnvironmentSensor(BaseSensorOperator):
         if status in BatchClientHook.COMPUTE_ENVIRONMENT_INTERMEDIATE_STATUS:
             return False
 
-        # TODO: remove this if block when min_airflow_version is set to higher than 2.7.1
-        message = f"AWS Batch compute environment failed. AWS Batch compute environment status: {status}"
-        if self.soft_fail:
-            raise AirflowSkipException(message)
-        raise AirflowException(message)
+        raise AirflowException(
+            f"AWS Batch compute environment failed. AWS Batch compute environment status: {status}"
+        )
 
 
 class BatchJobQueueSensor(BaseSensorOperator):
@@ -225,6 +211,10 @@ class BatchJobQueueSensor(BaseSensorOperator):
         queue and as such a valid case.
 
     :param aws_conn_id: aws connection to use, defaults to 'aws_default'
+        If this is None or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
 
     :param region_name: aws region name associated with the client
     """
@@ -237,7 +227,7 @@ class BatchJobQueueSensor(BaseSensorOperator):
         self,
         job_queue: str,
         treat_non_existing_as_deleted: bool = False,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         region_name: str | None = None,
         **kwargs,
     ):
@@ -264,11 +254,7 @@ class BatchJobQueueSensor(BaseSensorOperator):
             if self.treat_non_existing_as_deleted:
                 return True
             else:
-                # TODO: remove this if block when min_airflow_version is set to higher than 2.7.1
-                message = f"AWS Batch job queue {self.job_queue} not found"
-                if self.soft_fail:
-                    raise AirflowSkipException(message)
-                raise AirflowException(message)
+                raise AirflowException(f"AWS Batch job queue {self.job_queue} not found")
 
         status = response["jobQueues"][0]["status"]
 
@@ -279,6 +265,4 @@ class BatchJobQueueSensor(BaseSensorOperator):
             return False
 
         message = f"AWS Batch job queue failed. AWS Batch job queue status: {status}"
-        if self.soft_fail:
-            raise AirflowSkipException(message)
         raise AirflowException(message)
